@@ -32,10 +32,16 @@ enum class UserAgentFeature {
   ACCOUNT_ID_MODE_REQUIRED,
   RESOLVED_ACCOUNT_ID,
   GZIP_REQUEST_COMPRESSION,
+  CREDENTIALS_ENV_VARS,
+  CREDENTIALS_PROFILE,
+  CREDENTIALS_PROFILE_PROCESS,
+  CREDENTIALS_IMDS,
+  CREDENTIALS_STS_ASSUME_ROLE,
 };
 
 class AWS_CORE_API UserAgent {
  public:
+  static Aws::String BusinessMetricForFeature(UserAgentFeature feature);
   explicit UserAgent(const ClientConfiguration& clientConfiguration, const Aws::String& retryStrategyName, const Aws::String& apiName);
   Aws::String SerializeWithFeatures(const Aws::Set<UserAgentFeature>& features) const;
   void SetApiName(const Aws::String& apiName) { m_api = apiName; }
@@ -53,6 +59,7 @@ class AWS_CORE_API UserAgent {
   const Aws::String m_retryStrategyName;
   const Aws::String m_execEnv;
   const Aws::String m_appId;
+  const Aws::String m_overrideUserAgent;
   const Aws::String m_customizations;
   Aws::Set<UserAgentFeature> m_features;
 };
